@@ -48,7 +48,7 @@ public:
     Q_PROPERTY(QString icon READ icon CONSTANT)
     Q_PROPERTY(QObject* parent READ parent CONSTANT)
     Q_PROPERTY(QUrl decoration READ decoration CONSTANT)
-    Q_PROPERTY(QVariantList subcategories READ subCategoriesVariant CONSTANT)
+    Q_PROPERTY(QVariantList subcategories READ subCategoriesVariant NOTIFY subCategoriesChanged)
     explicit Category(QSet<QString>  pluginNames, QObject* parent = nullptr);
 
     Category(const QString& name, const QString& iconName, const QVector< QPair< FilterType, QString > >& orFilters, const QSet<QString> &pluginName, const QVector<Category *>& subCategories, const QUrl& decoration, bool isAddons);
@@ -62,7 +62,8 @@ public:
     QVector<Category *> subCategories() const;
     QVariantList subCategoriesVariant() const;
 
-    static void addSubcategory(QVector<Category*>& list, Category* cat);
+    static void sortCategories(QVector<Category*>& cats);
+    static void addSubcategory(QVector<Category*>& cats, Category* cat);
     void parseData(const QString& path, const QDomNode& data);
     bool blacklistPlugins(const QSet<QString>& pluginName);
     bool isAddons() const { return m_isAddons; }
@@ -73,6 +74,10 @@ public:
     Q_SCRIPTABLE bool contains(const QVariantList &cats) const;
 
     static bool categoryLessThan(Category *c1, const Category *c2);
+    static bool blacklistPluginsInVector(const QSet<QString>& pluginNames, QVector<Category *>& subCategories);
+
+Q_SIGNALS:
+    void subCategoriesChanged();
 
 private:
     QString m_name;
