@@ -25,7 +25,7 @@
 
 #include <QtCore/QStringBuilder>
 #include <KLocalizedString>
-#include <QDebug>
+#include "libdiscover_debug.h"
 
 UpdateItem::UpdateItem(AbstractResource *app)
     : m_app(app)
