@@ -538,3 +538,8 @@ QDate FlatpakResource::releaseDate() const
 
     return {};
 }
+
+QString FlatpakResource::sourceIcon() const
+{
+    return QStringLiteral("flatpak-discover");
+}
