@@ -28,11 +28,14 @@
 
 class SnapBackend;
 class QAbstractItemModel;
+class QSnapdClient;
+class QSnapdChannel;
 
 class SnapResource : public AbstractResource
 {
 Q_OBJECT
 Q_PROPERTY(QStringList objects MEMBER m_objects CONSTANT)
+Q_PROPERTY(QString channel READ channel WRITE setChannel NOTIFY channelChanged)
 public:
     explicit SnapResource(QSharedPointer<QSnapdSnap> snap, AbstractResource::State state, SnapBackend* parent);
     ~SnapResource() override = default;
@@ -56,7 +59,6 @@ public:
     void fetchChangelog() override;
     void fetchScreenshots() override;
     QList<PackageState> addonsInformation() override { return {}; }
-    QUrl url() const override;
     void setSnap(const QSharedPointer<QSnapdSnap> &snap);
 
     void setState(AbstractResource::State state);
@@ -64,15 +66,28 @@ public:
 
     QDate releaseDate() const override;
 
-    Q_SCRIPTABLE QAbstractItemModel* plugs(QObject* parents);
+    Q_SCRIPTABLE QAbstractItemModel* plugs(QObject* parentC);
+    Q_SCRIPTABLE QObject* channels(QObject* parent);
+    QString appstreamId() const override;
+
+    QString channel() const;
+    void setChannel(const QString &channel);
+
+    QSharedPointer<QSnapdSnap> snap() const { return m_snap; }
+
+Q_SIGNALS:
+    void channelChanged(const QString &channel);
+    void newSnap();
 
 public:
+    QSnapdClient* client() const;
+    void refreshSnap();
     void gotIcon();
     AbstractResource::State m_state;
 
     QSharedPointer<QSnapdSnap> m_snap;
     mutable QVariant m_icon;
-    const QStringList m_objects;
+    static const QStringList m_objects;
 };
 
 #endif // SNAPRESOURCE_H
