@@ -73,6 +73,10 @@ static int kIndexOf(const Q& list, W func)
     return -1;
 }
 
+template <typename Q, typename W>
+static bool kContains(const Q& list, W func)
+{ return kIndexOf(list, func) != -1; }
+
 template <typename T>
 static QVector<T> kSetToVector(const QSet<T> & set)
 {
